pub enum Error {
Overrun,
}๐Deprecated since 0.13.0:
The sercom::v1::spi module is deprecated, and will be removed in a subsequent release.
Please use the sercom::v2::spi module instead.
Variants
Overrun
๐Deprecated since 0.13.0:
The sercom::v1::spi module is deprecated, and will be removed in a subsequent release.
Please use the sercom::v2::spi module instead.